Struct WpLinuxDrmSyncobjManagerV1
pub struct WpLinuxDrmSyncobjManagerV1 { /* private fields */ }wayland and Linux only.Expand description
global for providing explicit synchronization
This global is a factory interface, allowing clients to request explicit synchronization for buffers on a per-surface basis.
See wp_linux_drm_syncobj_surface_v1 for more information.
This interface has no events.
Implementations
impl WpLinuxDrmSyncobjManagerV1
impl WpLinuxDrmSyncobjManagerV1
pub fn destroy(&self)
pub fn destroy(&self)
destroy explicit synchronization factory object
Destroy this explicit synchronization factory object. Other objects shall not be affected by this request.
pub fn get_surface<U, D>(
&self,
surface: &WlSurface,
qh: &QueueHandle<D>,
udata: U,
) -> WpLinuxDrmSyncobjSurfaceV1
pub fn get_surface<U, D>( &self, surface: &WlSurface, qh: &QueueHandle<D>, udata: U, ) -> WpLinuxDrmSyncobjSurfaceV1
extend surface interface for explicit synchronization
Instantiate an interface extension for the given wl_surface to provide explicit synchronization.
If the given wl_surface already has an explicit synchronization object associated, the surface_exists protocol error is raised.
Graphics APIs, like EGL or Vulkan, that manage the buffer queue and commits of a wl_surface themselves, are likely to be using this extension internally. If a client is using such an API for a wl_surface, it should not directly use this extension on that surface, to avoid raising a surface_exists protocol error.
pub fn import_timeline<U, D>(
&self,
fd: BorrowedFd<'_>,
qh: &QueueHandle<D>,
udata: U,
) -> WpLinuxDrmSyncobjTimelineV1
pub fn import_timeline<U, D>( &self, fd: BorrowedFd<'_>, qh: &QueueHandle<D>, udata: U, ) -> WpLinuxDrmSyncobjTimelineV1
import a DRM syncobj timeline
Import a DRM synchronization object timeline.
If the FD cannot be imported, the invalid_timeline error is raised.